"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from ragie.types import BaseModel
from typing import TypedDict


class UpdateInstructionParamsTypedDict(TypedDict):
    active: bool
    r"""Whether the instruction is active. Active instructions are applied to documents when they're created or when their file is updated."""
    

class UpdateInstructionParams(BaseModel):
    active: bool
    r"""Whether the instruction is active. Active instructions are applied to documents when they're created or when their file is updated."""
    
