"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from ragie.types import BaseModel
from typing import TypedDict


class DocumentDeleteTypedDict(TypedDict):
    status: str
    

class DocumentDelete(BaseModel):
    status: str
    
