"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from ragie.types import BaseModel
from ragie.utils import FieldMetadata, PathParamMetadata
from typing import TypedDict
from typing_extensions import Annotated


class DeleteDocumentRequestTypedDict(TypedDict):
    document_id: str
    r"""The id of the document."""
    

class DeleteDocumentRequest(BaseModel):
    document_id: Annotated[str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))]
    r"""The id of the document."""
    
